pitchtools.chromatic_pitch_number_and_accidental_semitones_to_octave_number
===========================================================================

.. autofunction:: abjad.tools.pitchtools.chromatic_pitch_number_and_accidental_semitones_to_octave_number.chromatic_pitch_number_and_accidental_semitones_to_octave_number
